pub enum FontCacheError<E> {
UserError(E),
NoLoadedFont(String),
NoRenderedFace(String, f32),
MissingGlyph(char),
}Expand description
Drawing text is no easy business. Here’s a list of everything that could go wrong.
Variants
UserError(E)
An error that comes from the bitmap transformation
NoLoadedFont(String)
The font has not been loaded
NoRenderedFace(String, f32)
A face has not been loaded and then rendered
MissingGlyph(char)
A glyph is missing from the font file