DrawCommand

Struct DrawCommand 

pub struct DrawCommand<'a, T: 'a> {
    pub bitmap: &'a T,
    pub bitmap_location: Rect,
    pub draw_location: (f32, f32),
}
A command instructing the user on how to draw a single character.

Fields

bitmap: &'a T

The bitmap that contains the character

bitmap_location: Rect

The location of the character in the bitmap

draw_location: (f32, f32)

The location on the screen to draw the character