FaceCache

Struct FaceCache 

pub struct FaceCache<T> { /* private fields */ }
A cache for a single font/size pairing.

Implementations

Source

impl<T> FaceCache<T>

pub fn new<I, F, E>( font: Font, scale: f32, chars: I, f: F, ) -> Result<FaceCache<T>, E>
where I: Iterator<Item = char>, F: Fn(Bitmap) -> Result<T, E>,

Constructs a new FaceCache of a font at a specific scale.

The characters in chars are pre-loaded into the atlas. If you need any more characters to draw things with, use prepare_string.

pub fn prepare_string<F, E>(&mut self, s: &str, f: F) -> Result<(), E>
where F: Fn(Bitmap) -> Result<T, E>,

Adds all the characters in the given string to the cache.

pub fn needs_preparing(&self, s: &str) -> bool

Returns true if a call to prepare_string is necessary to draw this string.

pub fn drawing_commands( &self, s: &str, ) -> Result<Vec<DrawCommand<'_, T>>, FontCacheError<Void>>

Returns a vector of drawing commands that describe how to lay out characters for printing

pub fn drawing_commands_prepared<F, E>( &mut self, s: &str, f: F, ) -> Result<Vec<DrawCommand<'_, T>>, E>
where F: Fn(Bitmap) -> Result<T, E>,

Returns a Vec of DrawCommands that pre-prepare the face-cache for drawing.

The only way that this will fail is if the rendering function f fails.